@@ -43,7 +43,8 @@ def get_atom_fea_name(structure: Structure) -> List[dict]:
     Returns:
         a list of site fraction description
     """
-    return [i.species.as_dict() for i in structure.sites]
+    return [{i.element.symbol:1} for i in structure.species]
+    # return [i.species.to_dict() for i in structure.sites]
 
 
 ##############################################################
@@ -72,6 +73,7 @@ class AtomMap(Converter, ABC):
         return oedata
 
 
+
 class BinaryMap(AtomMap):
     """Base converter with 2 different search_tp."""
 
@@ -86,10 +88,20 @@ class BinaryMap(AtomMap):
 
     def _convert(self, d: Any) -> Any:
         if self.search_tp == "name":
+            if isinstance(d, Structure):
+                d = get_atom_fea_name(d)
             return self.convert_dict(d)
         else:
+            if isinstance(d, Structure):
+                d = get_atom_fea_number(d)
             return self.convert_number(d)
 
+    def convert_structure(self, st):
+        if self.search_tp == "name":
+            return self.convert_dict(get_atom_fea_name(st))
+        else:
+            return self.convert_number(get_atom_fea_number(st))
+
     @abstractmethod
     def convert_dict(self, d: List[Dict]):
         """convert list of dict to data"""
@@ -121,7 +133,7 @@ class AtomJsonMap(BinaryMap):
     >>> s = [1,76]                   #[i.specie.Z for i in structure]
     >>> a = tmps.convert(s)
     >>> tmps = AtomJsonMap(search_tp="name")
-    >>> s = [{"H": 2, }, {"Al": 1}]  #[i.species.as_dict() for i in pymatgen.structure.sites]
+    >>> s = [{"H": 2, }, {"Al": 1}]  #[i.species.as_dict() for i in pymatgen_structure.sites]
     >>> a = tmps.convert(s)
     >>>
     >>> tmps = AtomJsonMap(search_tp="name")
@@ -183,14 +195,14 @@ class AtomJsonMap(BinaryMap):
             emb = 0
             for k, v in atom.items():
                 if self.weight:
-                    emb += np.array(self.embedding_dict[k]) * v
+                    emb += np.array(self.embedding_dict[k]).astype(np.float32) * v
                 else:
-                    emb += np.array(self.embedding_dict[k])
+                    emb += np.array(self.embedding_dict[k]).astype(np.float32)
             features.append(emb)
         if len(atoms) ==1:
-            return np.array(features).ravel()
+            return np.array(features).ravel().astype(np.float32)
         else:
-            return np.array(features).reshape((len(atoms), -1))
+            return np.array(features).reshape((len(atoms), -1)).astype(np.float32)
 
     def convert_number(self, atoms: List[int]) -> np.ndarray:
 
@@ -198,9 +210,9 @@ class AtomJsonMap(BinaryMap):
         features = [self.embedding_dict[i] for i in atoms_name]
 
         if len(atoms) == 1:
-            return np.array(features).ravel()
+            return np.array(features).astype(np.float32).ravel()
         else:
-            return np.array(features).reshape((len(atoms), -1))
+            return np.array(features).astype(np.float32).reshape((len(atoms), -1))
 
 
 class AtomTableMap(BinaryMap):
@@ -264,23 +276,29 @@ class AtomTableMap(BinaryMap):
 
         super(AtomTableMap, self).__init__(search_tp=search_tp, **kwargs)
 
-        if tablename is None or tablename == "element_table.csv":
+        if tablename is None:
             self.da = self.get_ele_embeddings()
             self.d2 = True
             self.dax = self.da.values
             self.da_columns = list(self.da.columns)
 
         elif isinstance(tablename, str):
-            self.da = self.get_csv_embeddings(tablename)
+            if tablename == "element_table.csv":
+                self.da = self.get_ele_embeddings()
+            else:
+                self.da = self.get_csv_embeddings(tablename)
             self.dax = self.da.values
             self.da_columns = list(self.da.columns)
 
         elif isinstance(tablename, np.ndarray):
             self.da_columns = None
-            self.dax = tablename
+            self.dax = tablename.astype(np.float32)
             self.d2 = False
+
         elif isinstance(tablename, pd.DataFrame):
+            tablename = tablename.apply(pd.to_numeric)
             self.da = tablename
+            self.dax = self.da.values
             self.d2 = True
             self.da_columns = list(self.da.columns)
         else:
@@ -708,4 +726,4 @@ class _StructurePymatgenPropMap(BaseFeature):
 
             nall.extend(ni)
         self._feature_labels = nall
-        return self._feature_labels
+        return self._feature_labels
\ No newline at end of file
