@@ -236,7 +236,8 @@ class BaseFeature(MSONable):
                     con = self.convert(x)
                 except TypeError as e:
                     print(e)
-                    raise TypeError("If the parameters should be unpack, please change the case to tuple, "
+                    raise TypeError("Please check the above errors ,"
+                                    "If the parameters should be unpack, please change the case to tuple, "
                                     "the other type(like list) would just pass to the first parameter integrally")
 
             if isinstance(con, (List, Tuple)):
@@ -284,9 +285,11 @@ class BaseFeature(MSONable):
             if d.ndim == 3:
                 return np.array([[self._convert(i) for i in di] for di in d])
 
-        elif isinstance(d, (list, tuple, int, float, dict)):
+        try:
             return np.array(self._convert(d))
-        raise NotImplementedError("just accept 1d,2d np.array or list, dict")
+        except BaseException as e:
+            print(e)
+            raise ValueError("Error when try to convert: \n {}".format(str(d)))
 
     @property
     def feature_labels(self):
