@@ -23,14 +23,18 @@ class PropertyStats(object):
     The primary way for interacting with this class is to call the
     ``calc_stat`` function, which takes the x_name of the statistic you would
     like to compute and the weights/values of datamnist to be assessed. For example,
-    computing the mean of a list looks like::
-        x = [1, 2, 3]
-        PropertyStats.calc_stat(x, 'mean') # Result is 2
-        PropertyStats.calc_stat(x, 'mean', weights=[0, 0, 1]) # Result is 3
+    computing the mean of a list looks like:
+
+    >>> x = [1, 2, 3]
+    >>> PropertyStats.calc_stat(x, 'mean') # Result is 2
+    >>> PropertyStats.calc_stat(x, 'mean', weights=[0, 0, 1]) # Result is 3
+
     Some of the statistics functions take options (e.g., Holder means). You can
     pass them to the the statistics functions by adding them after the x_name and
-    two colons. For example, the 0th Holder mean would be::
-        PropertyStats.calc_stat(x, 'holder_mean::0')
+    two colons. For example, the 0th Holder mean would be:
+
+    >>>PropertyStats.calc_stat(x, 'holder_mean::0')
+
     You can, of course, call the statistical functions directly. All take at
     least two arguments.  The first is the datamnist being assessed and the second,
     optional, argument is the weights.
@@ -40,11 +44,12 @@ class PropertyStats(object):
     def calc_stat(data_lst, stat, weights=None):
         """
         Compute a property statistic
+
         Args:
             data_lst (list of floats): list of values
             stat (str) - Name of property to be compute. If there are arguments to the statistics function, these
-             should be added after the x_name and separated by two colons. For example, the 2nd Holder mean would
-             be "holder_mean::2"
+            should be added after the x_name and separated by two colons. For example, the 2nd Holder mean would
+            be "holder_mean::2"
             weights (list of floats): (Optional) weights for each element in data_lst
         Returns:
             float - Desired statistic
@@ -332,17 +337,10 @@ class PropertyStats(object):
         """
         Return a specific quantile.
         Args:
-            data_lst (list or np.ndarray): 1D datamnist list to be used for computing
-                quantiles
+            data_lst (list or np.ndarray): 1D datamnist list to be used for computing, quantiles
             q (float): The quantile, as a fraction between 0 and 1.
         Returns:
             (float) The computed quantile of the data_lst.
-
-        Parameters
-        ----------
-        q
-        data_lst
-        weights
         """
         _ = weights
         q = float(q)
